matrix_to_raster: Matrix to Raster
Description
Turns a matrix into a Raster
Usage
matrix_to_raster(matrix, raster, crs = NULL)
Arguments
- matrix
The input matrix, typically the output of a rayshader operation
- raster
The original raster from which matrix is derived. Can be an Extent object.
- crs
If an Extent object is passed to the raster option, the corresponding coordinate reference system information.